Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2756)

Unified Diff: chrome/android/java/src/org/chromium/chrome/browser/tab/TabObserver.java

Issue 2408523002: Pass extra parameter to the Java WebContentsDelegateAndroid. (Closed)
Patch Set: Add parameter to TabWebContentsDelegateAndroid and TabObserver. Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/java/src/org/chromium/chrome/browser/tab/TabObserver.java
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/tab/TabObserver.java b/chrome/android/java/src/org/chromium/chrome/browser/tab/TabObserver.java
index d10d0fa20cfa3883bf6ccb5ccf9d238a5cc3436b..01d4a75c728b11cd0b140193359137c28742d23b 100644
--- a/chrome/android/java/src/org/chromium/chrome/browser/tab/TabObserver.java
+++ b/chrome/android/java/src/org/chromium/chrome/browser/tab/TabObserver.java
@@ -293,15 +293,17 @@ public interface TabObserver {
/**
* Called when a {@link WebContents} object has been created.
- * @param tab The notifying {@link Tab}.
- * @param sourceWebContents The {@link WebContents} that triggered the creation.
- * @param openerRenderFrameId The opener render frame id.
- * @param frameName The name of the frame.
- * @param targetUrl The target url.
- * @param newWebContents The newly created {@link WebContents}.
- */
- public void webContentsCreated(Tab tab, WebContents sourceWebContents, long openerRenderFrameId,
- String frameName, String targetUrl, WebContents newWebContents);
+ * @param tab The notifying {@link Tab}.
+ * @param sourceWebContents The {@link WebContents} that triggered the creation.
+ * @param openerRenderProcessId The opener render process id.
+ * @param openerRenderFrameId The opener render frame id.
+ * @param frameName The name of the frame.
+ * @param targetUrl The target url.
+ * @param newWebContents The newly created {@link WebContents}.
+ */
+ public void webContentsCreated(Tab tab, WebContents sourceWebContents,
+ long openerRenderProcessId, long openerRenderFrameId, String frameName,
+ String targetUrl, WebContents newWebContents);
/**
* Called when the tab reparenting process has finished.

Powered by Google App Engine
This is Rietveld 408576698